@@ -60,12 +60,27 @@ const char * tracktype2mimetype(uint32_t type)
   return "unknown";
 }
 
-void read_file(const char* filename)
+const char * errorstring(int32_t error)
+{
+  if (error >= MP4PARSE_OK) {
+    return "Ok";
+  }
+  switch (error) {
+    case MP4PARSE_ERROR_BADARG: return "Invalid argument";
+    case MP4PARSE_ERROR_INVALID: return "Invalid data";
+    case MP4PARSE_ERROR_UNSUPPORTED: return "Feature unsupported";
+    case MP4PARSE_ERROR_EOF: return "Unexpected end-of-file";
+    case MP4PARSE_ERROR_IO: return "I/O error";
+  }
+  return "Unknown error";
+}
+
+int32_t read_file(const char* filename)
 {
   FILE* f = fopen(filename, "rb");
   assert(f != nullptr);
 
-  size_t len = 4096;
+  size_t len = 4096*16;
   std::vector<uint8_t> buf(len);
   size_t read = fread(buf.data(), sizeof(decltype(buf)::value_type), buf.size(), f);
   buf.resize(read);
@@ -76,10 +91,14 @@ void read_file(const char* filename)
 
   fprintf(stderr, "Parsing %lu byte buffer.\n", (unsigned long)read);
   int32_t rv = mp4parse_read(context, buf.data(), buf.size());
-  assert(rv >= 0);
-  fprintf(stderr, "%d tracks returned to C code.\n", rv);
+  if (rv != MP4PARSE_OK) {
+    fprintf(stderr, "Parsing failed: %s\n", errorstring(rv));
+    return rv;
+  }
+  uint32_t tracks = mp4parse_get_track_count(context);
+  fprintf(stderr, "%u tracks returned to C code.\n", tracks);
 
-  for (int i = 0; i < rv; ++i) {
+  for (uint32_t i = 0; i < tracks; ++i) {
     mp4parse_track_info track_info;
     int32_t rv2 = mp4parse_get_track_info(context, i, &track_info);
     assert(rv2 >= 0);
@@ -88,6 +107,8 @@ void read_file(const char* filename)
   }
 
   mp4parse_free(context);
+
+  return MP4PARSE_OK;
 }
 
 int main(int argc, char* argv[])
